This directory contains different examples related to hydrodynamics:

- WaveKinematics:
    Plot the wave kinematics (elevation, velocity, acceleration) for linear waves
    Different locations, times and superposition of frequencies can be used.
- Jonswap spectrum: 
    Plot the JONSWAP spectrum for a given sea state
- WaveTimeSeries:
    Generate wave time series based on the Jonswap spectrum
- WaveLoads:
    Compute inline/total hydrodynamic force and moments on a monopile using Morison's equation
